@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/pkg/bin/python3.11
 # -*- coding: utf-8 -*-
 
 """
@@ -46,7 +46,10 @@ import select
 import re
 import traceback
 import binascii
-import collections
+try:
+    from collections.abc import Callable
+except ImportError:
+    from collections import Callable
 import numbers
 
 TAG_INPUT                       = 0
@@ -71,7 +74,11 @@ REJECT_PROMPT = '_THIS_CANNOT_BE_A_PROMPT_'
 we_are_running_under_rlwrap = 'RLWRAP_COMMAND_PID' in os.environ
 
 # rlwrap version
-rlwrap_version = float(os.environ.get('RLWRAP_VERSION', "0.41"))
+rlwrap_version_string  = os.environ.get('RLWRAP_VERSION', "0.41") # e.g. 0.45.2b
+major, rest            = rlwrap_version_string.split('.', 1)      # 0, 45.2b
+rest                   = re.sub(r'[^\d]','', rest)                # 452
+rlwrap_version         = float(major + '.' + rest)                # 0.452
+
 
 # open communication lines with rlwrap (or with the terminal when not running under rlwrap)
 if (we_are_running_under_rlwrap):
@@ -323,7 +330,7 @@ def is_float(value):
 
 
 def is_callable(value):
-    return isinstance(value, collections.Callable) or value == None
+    return isinstance(value, Callable) or value == None
 
 
 @intercept_error
